==> skin.mimic-3.4.2.zip: skin.mimic/readme.md <==
<h1>mim·ic</h1>
<code>1. To imitate</code><br />
<code>Synonyms: resemble, look like, have the appearance of</code>

As its name implies, this skin owes much to the Kodi community. In no particular order, I'd like to thank the following individuals:

- BigNoid, for developing Aeon Nox, on which this skin is based.
- Jeroen, for creating reFocus and some of the views included here.
- BobCratchett, for creating the skinshortcuts script and updating Mimic to use its latest features.
- Phil65, for the ExtendedInfo script and the selected item animation that is used throughout Mimic.
- Marcelveldt, for the skin helper service that makes the colour picker and so many other things possible.
- JurialMunkey, for Arctic Zephyr, which was the inspiration for the header and several other features.

And finally, all of the users, translators, testers, and fans of Mimic.

Support Kodi by donating @ http://kodi.tv/contribute/donate/

![Home Default] (http://i.imgur.com/5439sGH.jpg)

![Home Vertical] (http://i.imgur.com/LBLDthv.jpg)

More screenshots available here: http://imgur.com/a/LLSMM


***
**3.4.1**
- Added an option to limit the number of widget items.
- Added an option for wide list when using List view.
- Added an option for media flags in certain views.
- Added an option for icons on the vertical menu and fixed animations.
- Added a list view for the Settings window.
- Added country flags for Countries video node.
- Added more art options for Fanart view and removed Logo view.

***
**3.4.0**
- Added more art options for Thumbnail view.
- Redesigned vertical menu.
- Added alternative weather/time/date display on home screen.
- Added user ratings for music/videos.
- Redesigned information dialogs.
- Added option for centered menus on default home layout.
- Converted widgets to use templates so they don't have to reload.
- Added about/credits screen in skin settings.
- Redesigned the select dialog.
- Added an option for wider main menu items.
- Replaced Thai font with Sawasdee.
- Added a new dialog for supported addons.
- Added a select dialog for actor info (credit to BigNoid).
- Added a header for the home screen.
- Redesigned widgets on the vertical layout.
- Added an option to separate the main menu and submenu on the vertical layout.
- Added an option for panel style widgets.

***
**3.3.1**
- Fix submenu visibility on default home layout for touch/mouse users.

***
**3.3.0**
- Major redesign of main menu, header and views, including new icons and font.

***
**3.2.0**
- Reconfigured overlay icons.
- Changed keyboard autocomplete to use plugin.program.autocomplete.
- Added status of add-ons in skin settings.
- Reconfigured color customizer to use skin.helper.service.
- Added support for weather fanart image resource addons.
- Reconfigured music viz background options, added support for script.colorbox.
- Skinned the Audio DSP Manager and Audio DSP Settings dialogs.

***
**3.1.1**
- Updated skin dependencies.
- Added skin setting to set home background override slideshow.
- Added oninfo actions for movie and episode widgets.

***
**3.1.0**
- BobCratchett updated Mimic to the latest skinshortcuts features. Thanks!
- Updated language files from Transifex.

***
**3.0.0**
- Updated Mimic for Kodi 16 Jarvis.
- Continued adding additional artwork options to several views.
- Added player controls to the side menu.

***
**2.3.0**
- Added a sidebar option to wrap the ShowCase view. It is now a fixed list by default.
- Added ability to seek by clicking progress bars.
- Reconfigured all media views and added additional artwork options (banner, landscape, logo).
- Reconfigured musicvideo section, all views now support square artwork only.
- Added a new logo view.
- Redesigned login screen.

***
**2.2.1**
- Skinned Rom Collection Browser dialogs.
- Added option to display plot/description on Shift view for videos/music.
- Added Shift view for episodes.
- Added Trailer button to context menu for movies.
- New default main menu.
- Added skin setting to change text color.

***
**2.2.0**
- Updated all of the panel views using Phil65's design.
- Added support for Phil65's YouTube Browser addon.
- Added YouTube videos to Artist/Album and Movie/TV Show info dialogs.
- Added a basic weather view.
- Added skin setting to change default background image.
- Added 8 custom widgets to skin settings.
- Added large icon option to InfoWall view for videos.
- Added extra fanart option to InfoWall, Showcase, and BannerInfo views for videos.
- Added support for Rom Collection Browser.

***
**2.1.2**
- Updated language files from Transifex.
- Added skin settings to import/export the skin settings.
- Added keyboard auto-complete via Extended Info script.
- Skinned T9 keyboard for Extended Info.
- Added support for Nextup Notification Service addon.
- Added blurred album cover background for music viz, courtesy of AN5.
- Changed Extended Info video list to Shift view.

***
**2.1.1**
- Added support for SimplePlaylists addon.
- Fixed LowList view for video/music addons, added it for picture addons.
- Updated language files from Transifex.

***
**2.1.0**
- Added two new home layouts: top menu and vertical menu.
- Added support for series recording with pvr.wmc.
- Fixed critical error with color customizer when enabled for the first time.
- Added skin setting to show submenus all the time on alternative home layouts.

***
**2.0.1**
- Added IMDb flag for views when sorted by Top 250.
- Added LowList view from Aeon Nox 5.
- Added skin setting to disable autoscroll for home widgets.
- Redesigned video bookmarks window.
- Replaced premade color themes with color customizer in skin settings.
- Added a sidebar menu for the Settings section and Global Search.
- Replaced similar artists with artist bio in music viz options.
- Added EPG support to Global Search (requires version 4.x).
- Updated language files from Transifex.

***
**2.0.0**
- Initial release for Kodi Isengard, includes updates to the skinning engine.
- Added a dialog to the sidebar for choosing view modes.
- Added a new Blue theme.
- Added support for The Big Picture addon.
- Consolidated addon views, added Shift view for addons.
- Updated language files from Transifex.
- Changed default theme to black-blue.
- Added support for LazyTV addon.

***
**1.1.1**
- Added back the option for home fanart overlay.

***
**1.1.0**
- Updated language files from Transifex.
- Added a Thai language font.
- Various bug fixes.
- Added option to animate music visualization fanart.
- Redesigned music/video now playing info on the home screen.
- Redesigned home screen widgets so they are part of the main menu.
- Redesigned Icon view for Pictures and added a setting to hide Picture filenames.
- Fixed musicvideo views and added new ones.

***
**1.0.4**
- Added skin setting to always display home screen widgets, rather than press up from main menu.
- Fixed list view posters for Files and Addons.
- Updated language files from Transifex.
- Removed color diffuse from TV channel logos.
- Added a serif font, NotoSerif.

***
**1.0.3**
- Updated language files from Transifex.
- Added Live TV now playing info to the home screen.
- Added video now playing info to the bottom bar.
- Changed home widgets to comply with wrap/fixed list setting.
- Added a white theme.
- Added mouse support for the media menu.
- Added extendedinfo to extras context menu, thx Warner306.
- Added drop shadows to dialogs and two additional options with BoldDialog and FlatDialog themes.

***
**1.0.2**
- Changed window animations.
- Fixed fanart overlay for Favourites and Global Search.
- Added additional info to Music/Addon list and slim list views.
- Added a full screen Wall view.
- Added foreign language support with Arial font.
- Made Webly Sleek UI the default font, added Roboto 2014.
- Replaced Logo view with Fanart view.
- Added a 7th line to the EPG.
- Added Black-Green, Black-Mauve, and Black-Purple color themes.
- Updated language files from Transifex.
- Added support for script.extendedinfo.
- Added an optional bottom bar to display now playing music info.

***
**1.0.1**
- Redesigned widgets on home screen.
- Removed option for genre fanart for video and music.
- Changed main menu to obey fixed horizontal list setting.
- Moved notifications to the right side of screen.
- Changed how InfoWall and BannerInfo handle missing fanart.
- Added setting to hide weather/clock on home screen.
- Updated rating stars to all use themecolor.
- Added panel view for Artists.
- Added a scrollbar to System Info window.
- Added a skin setting to remove fullscreen overlay on Home screen.
- Changed videoinfo actor list from labels to thumbs.
- Removed cdART from album info. Replaced with artist logo.
- Fixed display of parent folder items.
- Added infolines back to the topbar.
- Converted Favorites to a standard window with List and Icon views.

***
**1.0.0**
- Initial release.

==> skin.mimic-5.0.3.zip: skin.mimic/readme.md <==
![banner] (http://i.imgur.com/VfxG5Nw.jpg)
<h1>mim·ic</h1>
<code>1. To imitate</code><br />
<code>Synonyms: resemble, look like, have the appearance of</code>

As its name implies, this skin owes much to the Kodi community. In no particular order, I'd like to thank the following individuals:

- BigNoid, for developing Aeon Nox, on which this skin is based.
- Jeroen, for creating reFocus and some of the views included here.
- BobCratchett, for creating the skinshortcuts script and updating Mimic to use its latest features.
- Phil65, for the ExtendedInfo script and the selected item animation that is used throughout Mimic.
- Marcelveldt, for the skin helper service that makes the colour picker and so many other things possible.
- JurialMunkey, for Arctic Zephyr, which was the inspiration for the header and several other features.

And finally, all of the users, translators, testers, and fans of Mimic.

Support Kodi by donating @ http://kodi.tv/contribute/donate/

![Home Default] (https://github.com/braz96/skin.mimic/raw/master/resources/screenshot-01.jpg)

![Shift View] (https://github.com/braz96/skin.mimic/raw/master/resources/screenshot-06.jpg)



***
**5.0.3**
- Adjust views for video addons.
- Fix watched/unwatched indicator settings.
- Misc bug fixes.

***
**5.0.2**
- Added background overlay options.
- Added new widget styles based on content type.
- Redesigned lyrics, thx manfeed!.
- Enabled "More" menu on info dialog for video widgets and seasons.
- Fixed home backgrounds for submenu items.

***
**5.0.1**
- Reconfigured backgrounds options.

***
**5.0.0**
- Simplified home window, removed several options.
- Removed Live DVD background option (wasn't working).
- Added mouse support for submenus.
- Redesigned Addon, Extended Info, and Global Search info dialogs.
- Added more home background options via script.skin.helper.service.
- Removed dependency on script.grab.fanart.
- Implemented a context menu for the menu customizer.
- Removed ShowCase and Poster views.
- Redesigned InfoWall view.
- Added LowPanel view for Artists and Albums.
- Added LowList and InfoWall views for Sets.
- Added media flags for episode List view.
- Redesigned volume bar and extended progress bar dialogs (adapted from Estuary).
- Added button to side menu to edit library nodes.
- Removed light theme.
- Added option to customize disabled color.
- Added color theme management.
- Added default widgets for new installs.
- Added Shift view for Files.
- Added 2 column option for list view.
- Overhaul skin fonts.
- Rounded skin textures (based on Arctic Zephyr) and added square theme.
- Redesigned main menu.

***
**4.0.2**
- Added a quick launch menu to side menu.
- Redesigned player controls and video/music OSD buttons.

***
**4.0.1**
- Added new widget style for vertical home layout.
- Redesigned extended weather window.
- Moved extras menu to a helper script.
- Code cleanup.
- Removed cdART Manager and ROM Collection Browser skins.

***
**4.0.0**
- Initial release for Kodi 17 Krypton.

***
**3.4.1**
- Added an option to limit the number of widget items.
- Added an option for wide list when using List view.
- Added an option for media flags in certain views.
- Added an option for icons on the vertical menu and fixed animations.
- Added a list view for the Settings window.
- Added country flags for Countries video node.
- Added more art options for Fanart view and removed Logo view.

***
**3.4.0**
- Added more art options for Thumbnail view.
- Redesigned vertical menu.
- Added alternative weather/time/date display on home screen.
- Added user ratings for music/videos.
- Redesigned information dialogs.
- Added option for centered menus on default home layout.
- Converted widgets to use templates so they don't have to reload.
- Added about/credits screen in skin settings.
- Redesigned the select dialog.
- Added an option for wider main menu items.
- Replaced Thai font with Sawasdee.
- Added a new dialog for supported addons.
- Added a select dialog for actor info (credit to BigNoid).
- Added a header for the home screen.
- Redesigned widgets on the vertical layout.
- Added an option to separate the main menu and submenu on the vertical layout.
- Added an option for panel style widgets.

***
**3.3.1**
- Fix submenu visibility on default home layout for touch/mouse users.

***
**3.3.0**
- Major redesign of main menu, header and views, including new icons and font.

***
**3.2.0**
- Reconfigured overlay icons.
- Changed keyboard autocomplete to use plugin.program.autocomplete.
- Added status of add-ons in skin settings.
- Reconfigured color customizer to use skin.helper.service.
- Added support for weather fanart image resource addons.
- Reconfigured music viz background options, added support for script.colorbox.
- Skinned the Audio DSP Manager and Audio DSP Settings dialogs.

***
**3.1.1**
- Updated skin dependencies.
- Added skin setting to set home background override slideshow.
- Added oninfo actions for movie and episode widgets.

***
**3.1.0**
- BobCratchett updated Mimic to the latest skinshortcuts features. Thanks!
- Updated language files from Transifex.

***
**3.0.0**
- Updated Mimic for Kodi 16 Jarvis.
- Continued adding additional artwork options to several views.
- Added player controls to the side menu.

***
**2.3.0**
- Added a sidebar option to wrap the ShowCase view. It is now a fixed list by default.
- Added ability to seek by clicking progress bars.
- Reconfigured all media views and added additional artwork options (banner, landscape, logo).
- Reconfigured musicvideo section, all views now support square artwork only.
- Added a new logo view.
- Redesigned login screen.

***
**2.2.1**
- Skinned Rom Collection Browser dialogs.
- Added option to display plot/description on Shift view for videos/music.
- Added Shift view for episodes.
- Added Trailer button to context menu for movies.
- New default main menu.
- Added skin setting to change text color.

***
**2.2.0**
- Updated all of the panel views using Phil65's design.
- Added support for Phil65's YouTube Browser addon.
- Added YouTube videos to Artist/Album and Movie/TV Show info dialogs.
- Added a basic weather view.
- Added skin setting to change default background image.
- Added 8 custom widgets to skin settings.
- Added large icon option to InfoWall view for videos.
- Added extra fanart option to InfoWall, Showcase, and BannerInfo views for videos.
- Added support for Rom Collection Browser.

***
**2.1.2**
- Updated language files from Transifex.
- Added skin settings to import/export the skin settings.
- Added keyboard auto-complete via Extended Info script.
- Skinned T9 keyboard for Extended Info.
- Added support for Nextup Notification Service addon.
- Added blurred album cover background for music viz, courtesy of AN5.
- Changed Extended Info video list to Shift view.

***
**2.1.1**
- Added support for SimplePlaylists addon.
- Fixed LowList view for video/music addons, added it for picture addons.
- Updated language files from Transifex.

***
**2.1.0**
- Added two new home layouts: top menu and vertical menu.
- Added support for series recording with pvr.wmc.
- Fixed critical error with color customizer when enabled for the first time.
- Added skin setting to show submenus all the time on alternative home layouts.

***
**2.0.1**
- Added IMDb flag for views when sorted by Top 250.
- Added LowList view from Aeon Nox 5.
- Added skin setting to disable autoscroll for home widgets.
- Redesigned video bookmarks window.
- Replaced premade color themes with color customizer in skin settings.
- Added a sidebar menu for the Settings section and Global Search.
- Replaced similar artists with artist bio in music viz options.
- Added EPG support to Global Search (requires version 4.x).
- Updated language files from Transifex.

***
**2.0.0**
- Initial release for Kodi Isengard, includes updates to the skinning engine.
- Added a dialog to the sidebar for choosing view modes.
- Added a new Blue theme.
- Added support for The Big Picture addon.
- Consolidated addon views, added Shift view for addons.
- Updated language files from Transifex.
- Changed default theme to black-blue.
- Added support for LazyTV addon.

***
**1.1.1**
- Added back the option for home fanart overlay.

***
**1.1.0**
- Updated language files from Transifex.
- Added a Thai language font.
- Various bug fixes.
- Added option to animate music visualization fanart.
- Redesigned music/video now playing info on the home screen.
- Redesigned home screen widgets so they are part of the main menu.
- Redesigned Icon view for Pictures and added a setting to hide Picture filenames.
- Fixed musicvideo views and added new ones.

***
**1.0.4**
- Added skin setting to always display home screen widgets, rather than press up from main menu.
- Fixed list view posters for Files and Addons.
- Updated language files from Transifex.
- Removed color diffuse from TV channel logos.
- Added a serif font, NotoSerif.

***
**1.0.3**
- Updated language files from Transifex.
- Added Live TV now playing info to the home screen.
- Added video now playing info to the bottom bar.
- Changed home widgets to comply with wrap/fixed list setting.
- Added a white theme.
- Added mouse support for the media menu.
- Added extendedinfo to extras context menu, thx Warner306.
- Added drop shadows to dialogs and two additional options with BoldDialog and FlatDialog themes.

***
**1.0.2**
- Changed window animations.
- Fixed fanart overlay for Favourites and Global Search.
- Added additional info to Music/Addon list and slim list views.
- Added a full screen Wall view.
- Added foreign language support with Arial font.
- Made Webly Sleek UI the default font, added Roboto 2014.
- Replaced Logo view with Fanart view.
- Added a 7th line to the EPG.
- Added Black-Green, Black-Mauve, and Black-Purple color themes.
- Updated language files from Transifex.
- Added support for script.extendedinfo.
- Added an optional bottom bar to display now playing music info.

***
**1.0.1**
- Redesigned widgets on home screen.
- Removed option for genre fanart for video and music.
- Changed main menu to obey fixed horizontal list setting.
- Moved notifications to the right side of screen.
- Changed how InfoWall and BannerInfo handle missing fanart.
- Added setting to hide weather/clock on home screen.
- Updated rating stars to all use themecolor.
- Added panel view for Artists.
- Added a scrollbar to System Info window.
- Added a skin setting to remove fullscreen overlay on Home screen.
- Changed videoinfo actor list from labels to thumbs.
- Removed cdART from album info. Replaced with artist logo.
- Fixed display of parent folder items.
- Added infolines back to the topbar.
- Converted Favorites to a standard window with List and Icon views.

***
**1.0.0**
- Initial release.
